function [T,D] = haar(S)
%
% function [T,D] = haar(S)
%
% Decompose a signal given by kmin and array of amplitudes r into the 
% trend T and the detail D, using the Haar wavelet.
% By default, level is 1 (breaks at 1x integers). 
% level > 1 can be use to decompose (see haardec).
%
kmin = S.kmin;
r = S.amplitudes;
kmax = kmin+length(r)-1;
level = S.breaks;
if (mod(kmin,2) == 1)
  kmin = kmin-1;
  r(2:end+1) = r;
  r(1) = 0;
end
if (mod(kmax,2) == 0)
  kmax = kmax+1;
  r(end+1) = 0;
end
hmin = kmin/2;
hmax = (kmax-1)/2;
for i = 1:hmax-hmin+1
  u(i) = (r(2*i-1)+r(2*i))/2; 
  v(i) = (r(2*i-1)-r(2*i))/2; 
end
T.type = 'trend';
T.breaks = level+1;
T.kmin = hmin;
T.amplitudes = u;
D.type = 'detail';
D.breaks = level+1;
D.kmin = hmin;
D.amplitudes = v;